@@ -21,7 +21,8 @@ desc_stats <- function(vector = NULL, notify_na_count = NULL) {
   }
   if (notify_na_count == TRUE) {
     message(paste0(
-      na_count, " observation(s) were removed due to missing values."))
+      na_count, " observation(s) were removed due to missing values."
+    ))
   }
   # get stats
   n <- length(v_no_na)
@@ -33,11 +34,13 @@ desc_stats <- function(vector = NULL, notify_na_count = NULL) {
   se_of_mean <- kim::se_of_mean(v_no_na, notify_na_count = FALSE)
   skewness <- moments::skewness(v_no_na)
   kurtosis <- moments::kurtosis(v_no_na)
-  # combine into a named vector
-  statistic <- c(
+  # combine into a list
+  stats_list <- list(
     n, mean, sd, median, min, max, se_of_mean, skewness, kurtosis)
+  statistic <- vapply(stats_list, as.numeric, FUN.VALUE = numeric(1))
   names(statistic) <- c(
     "n", "mean", "sd", "median", "min", "max",
-    "se_of_mean", "skewness", "kurtosis")
+    "se_of_mean", "skewness", "kurtosis"
+  )
   return(statistic)
 }
